=======
History
=======

0.0.7 (2018-02-12)
------------------

* Lucky number 7
* Added more contributors
* Improved output formatting and coloring

0.0.4 (2018-02-10)
------------------

* Add jezdez and lamby
* Fix a trailing comma bug

0.0.3 (2018-02-10)
------------------

* Add more contributors
* Add json to manifest to make it actually work (thanks @martinmaillard)

0.0.1 (2018-02-10)
------------------

* First release on PyPI.
